#include <Adafruit_ESP8266.h>
#include <SoftwareSerial.h>

#define ESP_RX   8
#define ESP_TX   7
#define ESP_RST  4
SoftwareSerial softser(ESP_RX, ESP_TX);

Adafruit_ESP8266 wifi(&softser, &Serial, ESP_RST);

//#define HOST     "www.adafruit.com"     // Host to contact
//#define PAGE     "/testwifi/index.html" // Web page to request
//#define PORT     80                     // 80 = HTTP default port

char buffer[100];

boolean esp8266_setup() {

  // comment/replace this if you are using something other than v 0.9.2.4!
  wifi.setBootMarker(F("Version:0.9.2.4]\r\n\r\nready"));

  softser.begin(9600); // Soft serial connection to ESP8266

  Serial.print(F("Hard reset..."));
  if(!wifi.hardReset()) {
    Serial.println(F("no response from module."));
    return false;
  }
  Serial.println(F("OK."));

  Serial.print(F("Soft reset..."));
  if(!wifi.softReset()) {
    Serial.println(F("no response from module."));
    // return false;
  }
  Serial.println(F("OK."));

  Serial.print(F("Checking firmware version..."));
  wifi.println(F("AT+GMR"));
  if(wifi.readLine(buffer, sizeof(buffer))) {
    Serial.println(buffer);
    wifi.find(); // Discard the 'OK' that follows
    return true;
  } 
  else {
    Serial.println(F("error"));
    return false;
  }
}

boolean esp8266_connectAP(Fstr* ssid, Fstr* pass) {
  Serial.print(F("Connecting to WiFi..."));
  //  if(wifi.connectToAP(F(ESP_SSID), F(ESP_PASS))) {
  if(wifi.connectToAP(ssid, pass)) {

    // IP addr check isn't part of library yet, but
    // we can manually request and place in a string.
    Serial.print(F("OK\nChecking IP addr..."));
    wifi.println(F("AT+CIFSR"));
    if(wifi.readLine(buffer, sizeof(buffer))) {
      Serial.println(buffer);
      wifi.find(); // Discard the 'OK' that follows
      return true;
    } 
    else { // IP addr check failed
      Serial.println(F("error"));
      return false;
    }
    wifi.closeAP();
  } 
  else { // WiFi connection failed
    Serial.println(F("FAIL"));
    return false;
  }
}


boolean esp8266_connectTCP(Fstr *host, int port) {
  int try_count = 10;
  while(try_count > 0) {
    if(wifi.connectTCP(host, port)) {
      return true;
    }
    delay(100);
  }
  return false;
}

boolean esp8266_requestURL(char *page, char* method) {
  return wifi.requestURL(page, method);
}

void esp8266_closeTCP() {
  wifi.closeTCP();
}




